summaryrefslogtreecommitdiffhomepage
path: root/Opcode/Ice/IcePlane.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'Opcode/Ice/IcePlane.cpp')
-rw-r--r--Opcode/Ice/IcePlane.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/Opcode/Ice/IcePlane.cpp b/Opcode/Ice/IcePlane.cpp
index 36fe473..cd4758c 100644
--- a/Opcode/Ice/IcePlane.cpp
+++ b/Opcode/Ice/IcePlane.cpp
@@ -25,16 +25,16 @@ using namespace IceMaths;
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/**
* Computes the plane equation from 3 points.
* \param p0 [in] first point
* \param p1 [in] second point
* \param p2 [in] third point
* \return Self-reference
*/
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-Plane& Plane::Set(const Point& p0, const Point& p1, const Point& p2)
+Plane& Plane::Set(const IcePoint& p0, const IcePoint& p1, const IcePoint& p2)
{
- Point Edge0 = p1 - p0;
- Point Edge1 = p2 - p0;
+ IcePoint Edge0 = p1 - p0;
+ IcePoint Edge1 = p2 - p0;
n = Edge0 ^ Edge1;
n.Normalize();
@@ -25,16 +25,16 @@ using namespace IceMaths;
/**
* Computes the plane equation from 3 points.
- * \param p0 [in] first point
- * \param p1 [in] second point
- * \param p2 [in] third point
+ * \param p0 [in] first IcePoint
+ * \param p1 [in] second IcePoint
+ * \param p2 [in] third IcePoint
* \return Self-reference
*/